@@ -47,6 +47,7 @@ from .compat import (
     urlsplit,
     parse_qs,
     ClassTypes,
+    basestring
 )
 from .http import (
     STATUSES,
@@ -75,6 +76,8 @@ old_ssl_wrap_socket = None
 old_sslwrap_simple = None
 old_sslsocket = None
 
+if PY3:
+    basestring = (bytes, str)
 try:
     import socks
     old_socksocket = socks.socksocket
